@@ -28,7 +28,7 @@
 #include <stdio.h>
 #include <stdarg.h>
 
-int snprintf(char *str, size_t size, const char *format, ...){
+int rpl_snprintf(char *str, size_t size, const char *format, ...){
     va_list ap;
     int r;
 
