@@ -37,6 +37,7 @@
 #include <unistd.h>
 #include <signal.h>
 #include <sys/types.h>
+#include <errno.h>
 
 #include <X11/Xlib.h>
 #include <X11/xpm.h>
@@ -105,6 +106,21 @@ void sigusr1(int i){
         warn("Error setting SIGUSR1 signal handler!");
 }
 
+void sigfunc(int i){
+    sigs |= i<<8;
+    if(signal(i, sigfunc)==SIG_ERR)
+        warn("Error setting %d signal handler!", i);
+}
+
+void do_cleanup(void){
+    metar_cleanup();
+    warnings_cleanup();
+    avn_cleanup();
+    eta_cleanup();
+    mrf_cleanup();
+    radar_cleanup();
+}
+
 void init_dock(int argc, char **argv){
     sscanf(wmweather_master_xpm[0], "%d %d %*s", &wmweather_mask_width, &wmweather_mask_height);
     wmweather_mask_bits=malloc((wmweather_mask_width+7)/8*wmweather_mask_height);
@@ -127,6 +143,8 @@ void init_dock(int argc, char **argv){
     if(eta_station) init_eta();
     if(mrf_station) init_mrf();
     init_radar();
+    errno=0;
+    if(atexit(do_cleanup)) warn("atexit() failed, files will not be cleaned up\n");
 
     current_mode=starting_mode;
     window_X=0; window_Y=0;
@@ -152,6 +170,14 @@ void init_dock(int argc, char **argv){
         warn("Error setting SIGUSR1 signal handler!");
     if(signal(SIGUSR2, sigusr2)==SIG_ERR)
         warn("Error setting SIGUSR2 signal handler!");
+    if(signal(SIGHUP, sigfunc)==SIG_ERR)
+        warn("Error setting SIGHUP signal handler!");
+    if(signal(SIGINT, sigfunc)==SIG_ERR)
+        warn("Error setting SIGINT signal handler!");
+    if(signal(SIGPIPE, sigfunc)==SIG_ERR)
+        warn("Error setting SIGPIPE signal handler!");
+    if(signal(SIGTERM, sigfunc)==SIG_ERR)
+        warn("Error setting SIGTERM signal handler!");
 
     DrawDisplay(1);
 }
@@ -165,6 +191,7 @@ void update_dock(){
     j=sigs;
     sigs=0;
     if(j){
+        if(j&~3) exit(j);
         if(j&1) i=current_mode;
         if(j&2) i=-1;
         if(j&3){
