@@ -731,11 +731,11 @@ int main(int argc, char **argv){
     if(mrf_uri==NULL) mrf_uri="http://www.nws.noaa.gov/cgi-bin/mos/getmex.pl?sta=%s";
     if(warning_uri==NULL) warning_uri="http://weather.noaa.gov/pub/data/watches_warnings/%f/%.2z/%z.txt";
 
-    DownloadInit(email_address);
+    download_init(email_address);
     init_dock(argc, argv);
     while(1){
         update_dock();
-        ProcessDownloads(100000);
+        download_process(100000);
     }
 }
 
